==> map-4.14.jar: org/apache/batik/svggen/SVGPaintDescriptor.java <==
/*

   Copyright 2001,2003  The Apache Software Foundation 

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
package org.apache.batik.svggen;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import org.w3c.dom.Element;

/**
 * Used to represent an SVG Paint. This can be achieved with
 * to values: an SVG paint value and an SVG opacity value
 *
 * @author <a href="mailto:vincent.hardy@eng.sun.com">Vincent Hardy</a>
 * @version $Id: SVGPaintDescriptor.java,v 1.6 2004/08/18 07:15:08 vhardy Exp $
 */
public class SVGPaintDescriptor implements SVGDescriptor, SVGSyntax{
    private Element def;
    private String paintValue;
    private String opacityValue;

    public SVGPaintDescriptor(final String paintValue,
                              final String opacityValue){
        this.paintValue = paintValue;
        this.opacityValue = opacityValue;
    }

    public SVGPaintDescriptor(final String paintValue,
                              final String opacityValue,
                              final Element def){
        this(paintValue, opacityValue);
        this.def = def;
    }

    public String getPaintValue(){
        return this.paintValue;
    }

    public String getOpacityValue(){
        return this.opacityValue;
    }

    public Element getDef(){
        return this.def;
    }

    public Map getAttributeMap(Map attrMap){
        if(attrMap == null)
            attrMap = new HashMap();

        attrMap.put(SVG_FILL_ATTRIBUTE, this.paintValue);
        attrMap.put(SVG_STROKE_ATTRIBUTE, this.paintValue);
        attrMap.put(SVG_FILL_OPACITY_ATTRIBUTE, this.opacityValue);
        attrMap.put(SVG_STROKE_OPACITY_ATTRIBUTE, this.opacityValue);

        return attrMap;
    }

    public List getDefinitionSet(List defSet){
        if(defSet == null)
            defSet = new LinkedList();

        if(this.def != null)
            defSet.add(this.def);

        return defSet;
    }
}

==> map-4.16.jar: org/apache/batik/svggen/SVGPaintDescriptor.java <==
/*

   Copyright 2001,2003  The Apache Software Foundation 

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
package org.apache.batik.svggen;

import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.w3c.dom.Element;

/**
 * Used to represent an SVG Paint. This can be achieved with
 * to values: an SVG paint value and an SVG opacity value
 *
 * @author <a href="mailto:vincent.hardy@eng.sun.com">Vincent Hardy</a>
 * @version $Id: SVGPaintDescriptor.java,v 1.6 2004/08/18 07:15:08 vhardy Exp $
 */
public class SVGPaintDescriptor implements SVGDescriptor, SVGSyntax{
    private Element def;
    private String paintValue;
    private String opacityValue;

    public SVGPaintDescriptor(final String paintValue,
                              final String opacityValue){
        this.paintValue = paintValue;
        this.opacityValue = opacityValue;
    }

    public SVGPaintDescriptor(final String paintValue,
                              final String opacityValue,
                              final Element def){
        this(paintValue, opacityValue);
        this.def = def;
    }

    public String getPaintValue(){
        return this.paintValue;
    }

    public String getOpacityValue(){
        return this.opacityValue;
    }

    public Element getDef(){
        return this.def;
    }

    public Map getAttributeMap(Map attrMap){
        if(attrMap == null)
            attrMap = new ConcurrentHashMap();

        attrMap.put(SVG_FILL_ATTRIBUTE, this.paintValue);
        attrMap.put(SVG_STROKE_ATTRIBUTE, this.paintValue);
        attrMap.put(SVG_FILL_OPACITY_ATTRIBUTE, this.opacityValue);
        attrMap.put(SVG_STROKE_OPACITY_ATTRIBUTE, this.opacityValue);

        return attrMap;
    }

    public List getDefinitionSet(List defSet){
        if(defSet == null)
            defSet = new LinkedList();

        if(this.def != null)
            defSet.add(this.def);

        return defSet;
    }
}
